==> nrf51-pac-0.10.1.crate: nrf51-pac-0.10.1/src/radio/override1.rs <==
#[doc = "Register `OVERRIDE1` reader"]
pub struct R(crate::R<OVERRIDE1_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<OVERRIDE1_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<OVERRIDE1_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<OVERRIDE1_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `OVERRIDE1` writer"]
pub struct W(crate::W<OVERRIDE1_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<OVERRIDE1_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<OVERRIDE1_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<OVERRIDE1_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `OVERRIDE1` reader - Trim value override 1."]
pub struct OVERRIDE1_R(crate::FieldReader<u32, u32>);
impl OVERRIDE1_R {
    pub(crate) fn new(bits: u32) -> Self {
        OVERRIDE1_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for OVERRIDE1_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `OVERRIDE1` writer - Trim value override 1."]
pub struct OVERRIDE1_W<'a> {
    w: &'a mut W,
}
impl<'a> OVERRIDE1_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = (self.w.bits & !0xffff_ffff) | (value as u32 & 0xffff_ffff);
        self.w
    }
}
impl R {
    #[doc = "Bits 0:31 - Trim value override 1."]
    #[inline(always)]
    pub fn override1(&self) -> OVERRIDE1_R {
        OVERRIDE1_R::new((self.bits & 0xffff_ffff) as u32)
    }
}
impl W {
    #[doc = "Bits 0:31 - Trim value override 1."]
    #[inline(always)]
    pub fn override1(&mut self) -> OVERRIDE1_W {
        OVERRIDE1_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "Trim value override register 1.\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [override1](index.html) module"]
pub struct OVERRIDE1_SPEC;
impl crate::RegisterSpec for OVERRIDE1_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [override1::R](R) reader structure"]
impl crate::Readable for OVERRIDE1_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [override1::W](W) writer structure"]
impl crate::Writable for OVERRIDE1_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets OVERRIDE1 to value 0"]
impl crate::Resettable for OVERRIDE1_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> nrf51-pac-0.11.0.crate: nrf51-pac-0.11.0/src/radio/override1.rs <==
#[doc = "Register `OVERRIDE1` reader"]
pub struct R(crate::R<OVERRIDE1_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<OVERRIDE1_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<OVERRIDE1_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<OVERRIDE1_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `OVERRIDE1` writer"]
pub struct W(crate::W<OVERRIDE1_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<OVERRIDE1_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<OVERRIDE1_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<OVERRIDE1_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `OVERRIDE1` reader - Trim value override 1."]
pub struct OVERRIDE1_R(crate::FieldReader<u32, u32>);
impl OVERRIDE1_R {
    #[inline(always)]
    pub(crate) fn new(bits: u32) -> Self {
        OVERRIDE1_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for OVERRIDE1_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `OVERRIDE1` writer - Trim value override 1."]
pub struct OVERRIDE1_W<'a> {
    w: &'a mut W,
}
impl<'a> OVERRIDE1_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = value;
        self.w
    }
}
impl R {
    #[doc = "Bits 0:31 - Trim value override 1."]
    #[inline(always)]
    pub fn override1(&self) -> OVERRIDE1_R {
        OVERRIDE1_R::new(self.bits)
    }
}
impl W {
    #[doc = "Bits 0:31 - Trim value override 1."]
    #[inline(always)]
    pub fn override1(&mut self) -> OVERRIDE1_W {
        OVERRIDE1_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "Trim value override register 1.\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [override1](index.html) module"]
pub struct OVERRIDE1_SPEC;
impl crate::RegisterSpec for OVERRIDE1_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [override1::R](R) reader structure"]
impl crate::Readable for OVERRIDE1_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [override1::W](W) writer structure"]
impl crate::Writable for OVERRIDE1_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets OVERRIDE1 to value 0"]
impl crate::Resettable for OVERRIDE1_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
